"""Ferda hooks implementation."""

from typing import Any, Dict, Iterable, Tuple

import ferda

from ferda_verification.settings import SETTINGS

_PERMISSIONS = (
    ("ferda_verification.can_view", "Can view verification module"),
    ("ferda_verification.can_create", "Can create new verification"),
    ("ferda_verification.can_cancel", "Can cancel opened verification"),
    ("ferda_verification.can_approve_futile", "Can approve futile verifications"),
    ("ferda_verification.can_approve_manual", "Can approve manual verifications"),
    ("ferda_verification.can_delay_status", "Can delay verification status"),
    ("ferda_verification.can_resend_message", "Can resend verification message"),
    ("ferda_verification.can_resolve_manual_check", "Can resolve manual check"),
    ("ferda_verification.can_resume", "Can resume paused verifications"),
)


@ferda.hookimpl
def create_permissions() -> Iterable[Tuple[str, str]]:
    """Create ferda_verification permissions."""
    return _PERMISSIONS


@ferda.hookimpl
def show_settings() -> Dict[str, Any]:
    """Return context variables with ferda public request settings."""
    context = {
        "verification": {
            "verification_portal_url": SETTINGS.verification_portal_url,
        },
    }
    return context
